import { get_vuetify_options, i18n } from 'FerdaJS/app.config'
import Vue from 'vue'
import Vuetify from 'vuetify/lib'

import VerificationMenuItem from 'ferda_verification/common/VerificationMenuItem.vue'

import { i18next } from './main'

Vue.use(Vuetify)

/**
 * Waits for the element until it is present in the DOM
 *
 * @param { String } selector - particular node selector
 * @returns { Object } - resolved or rejected promise
 */
const wait_for_element = selector => {
    return new Promise(resolve => {
        // Return element if it is present
        const element = document.querySelector(selector)
        if (element) {
            resolve(element)
            return
        }

        // Otherwise observe for another mutation
        new MutationObserver((_, observer) => {
            for (const element of document.querySelectorAll(selector)) {
                resolve(element)
                observer.disconnect()
            }
        }).observe(document.documentElement, { childList: true, subtree: true })
    })
}

document.addEventListener('DOMContentLoaded', async() => {
    const permissions = JSON.parse(document.querySelector('#user-permissions').textContent)
    if (!permissions.includes('ferda_verification.can_view')) {
        return
    }

    // Wait until translations are ready
    await i18next.init()

    const menu = await wait_for_element('.v-navigation-drawer__content > div')
    const verification_item_el = document.createElement('div')
    verification_item_el.setAttribute('id', 'verification-item')
    menu.appendChild(verification_item_el)

    new Vue({
        el: '#verification-item',
        name: 'VerificationMenuItem',
        vuetify: new Vuetify(get_vuetify_options()),
        i18n,
        render: createElement => createElement(VerificationMenuItem),
    })
})
